@@ -174,7 +174,9 @@ type MachineCheckStatus struct {
 }
 
 type MachinePort struct {
-	Port       int      `json:"port" toml:"port"`
+	Port       *int32   `json:"port,omitempty" toml:"port,omitempty"`
+	StartPort  *int32   `json:"start_port,omitempty" toml:"start_port,omitempty"`
+	EndPort    *int32   `json:"end_port,omitempty" toml:"end_port,omitempty"`
 	Handlers   []string `json:"handlers,omitempty" toml:"handlers,omitempty"`
 	ForceHttps bool     `json:"force_https,omitempty" toml:"force_https,omitempty"`
 }
